==> zio-aws-macie2_2.12-6.20.97.2-sources.jar: zio/aws/macie2/model/CreateAllowListResponse.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.{
  __stringMin22Max22PatternAZ0922,
  __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateAllowListResponse(
    arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = Optional.Absent,
    id: Optional[__stringMin22Max22PatternAZ0922] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.CreateAllowListResponse = {
    import CreateAllowListResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.CreateAllowListResponse
      .builder()
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.CreateAllowListResponse.ReadOnly =
    zio.aws.macie2.model.CreateAllowListResponse.wrap(buildAwsValue())
}
object CreateAllowListResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.CreateAllowListResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.CreateAllowListResponse =
      zio.aws.macie2.model.CreateAllowListResponse(
        arn.map(value => value),
        id.map(value => value)
      )
    def arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ]
    def id: Optional[__stringMin22Max22PatternAZ0922]
    def getArn: ZIO[
      Any,
      AwsError,
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = AwsError.unwrapOptionField("arn", arn)
    def getId: ZIO[Any, AwsError, __stringMin22Max22PatternAZ0922] =
      AwsError.unwrapOptionField("id", id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.CreateAllowListResponse
  ) extends zio.aws.macie2.model.CreateAllowListResponse.ReadOnly {
    override val arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value =>
        value: __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
      )
    override val id: Optional[__stringMin22Max22PatternAZ0922] =
      zio.aws.core.internal
        .optionalFromNullable(impl.id())
        .map(value => value: __stringMin22Max22PatternAZ0922)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.CreateAllowListResponse
  ): zio.aws.macie2.model.CreateAllowListResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_3-7.28.26.1-sources.jar: zio/aws/macie2/model/CreateAllowListResponse.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.{
  __stringMin22Max22PatternAZ0922,
  __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateAllowListResponse(
    arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = Optional.Absent,
    id: Optional[__stringMin22Max22PatternAZ0922] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.CreateAllowListResponse = {
    import CreateAllowListResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.CreateAllowListResponse
      .builder()
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.CreateAllowListResponse.ReadOnly =
    zio.aws.macie2.model.CreateAllowListResponse.wrap(buildAwsValue())
}
object CreateAllowListResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.CreateAllowListResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.CreateAllowListResponse =
      zio.aws.macie2.model.CreateAllowListResponse(
        arn.map(value => value),
        id.map(value => value)
      )
    def arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ]
    def id: Optional[__stringMin22Max22PatternAZ0922]
    def getArn: ZIO[
      Any,
      AwsError,
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = AwsError.unwrapOptionField("arn", arn)
    def getId: ZIO[Any, AwsError, __stringMin22Max22PatternAZ0922] =
      AwsError.unwrapOptionField("id", id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.CreateAllowListResponse
  ) extends zio.aws.macie2.model.CreateAllowListResponse.ReadOnly {
    override val arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value =>
        value: __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
      )
    override val id: Optional[__stringMin22Max22PatternAZ0922] =
      zio.aws.core.internal
        .optionalFromNullable(impl.id())
        .map(value => value: __stringMin22Max22PatternAZ0922)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.CreateAllowListResponse
  ): zio.aws.macie2.model.CreateAllowListResponse.ReadOnly = new Wrapper(impl)
}
